from django.db import models


def get_related_field_name_for_object(obj, related_obj_instance):
    """Return the name of the field in obj's model that has a OneToOne relationship to related_obj_instance."""
    for field in obj._meta.get_fields():
        if isinstance(field, models.OneToOneField):
            if isinstance(related_obj_instance, field.related_model):
                return field.name
    return None


def dynamic_short_description(func):
    def wrapper(*args, **kwargs):
        instance = args[1] if args else None  # Assumes the model instance is the second argument
        if instance:
            field_name = get_related_field_name_for_object(
                instance,
                instance.curation_object,
            )
            if field_name:
                wrapper.short_description = field_name
        return func(*args, **kwargs)

    wrapper.short_description = func.__name__  # default name
    return wrapper
